==> qtjambi-qt3drender-5.15.5-sources.jar: io/qt/qt3d/render/QTextureCubeMap.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a TargetCubeMap target format</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtexturecubemap.html">Qt3DRender::QTextureCubeMap</a></p>
 */
public class QTextureCubeMap extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureCubeMap.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureCubeMap(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureCubeMap() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturecubemap.html#QTextureCubeMap">Qt3DRender::QTextureCubeMap::QTextureCubeMap(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureCubeMap(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureCubeMap instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMap(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMap(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTextureCubeMap instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QTextureCubeMap.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a TargetCubeMap target format</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtexturecubemap.html">Qt3DRender::QTextureCubeMap</a></p>
 */
public class QTextureCubeMap extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureCubeMap.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureCubeMap(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureCubeMap() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexturecubemap.html#QTextureCubeMap">Qt3DRender::QTextureCubeMap::QTextureCubeMap(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureCubeMap(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureCubeMap instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMap(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTextureCubeMap(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTextureCubeMap instance, QDeclarativeConstructor constructor);
    
}
